#
# PySNMP MIB module MPLS-LDP-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MPLS-LDP-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:21:17 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ConstraintsUnion, ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ConstraintsUnion", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint")
( IndexIntegerNextFree, IndexInteger, ) = mibBuilder.importSymbols("DIFFSERV-MIB", "IndexIntegerNextFree", "IndexInteger")
( InetAddress, InetPortNumber, InetAddressType, InetAddressPrefixLength, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetPortNumber", "InetAddressType", "InetAddressPrefixLength")
( MplsIndexType, ) = mibBuilder.importSymbols("MPLS-LSR-STD-MIB", "MplsIndexType")
( mplsStdMIB, MplsRetentionMode, MplsLdpIdentifier, MplsLspType, MplsLabelDistributionMethod, MplsLsrIdentifier, MplsLdpLabelType, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "mplsStdMIB", "MplsRetentionMode", "MplsLdpIdentifier", "MplsLspType", "MplsLabelDistributionMethod", "MplsLsrIdentifier", "MplsLdpLabelType")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, ObjectIdentity, ModuleIdentity, IpAddress, Bits, NotificationType, Counter64, Counter32, iso, MibIdentifier, Integer32, TimeTicks, Gauge32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "ObjectIdentity", "ModuleIdentity", "IpAddress", "Bits", "NotificationType", "Counter64", "Counter32", "iso", "MibIdentifier", "Integer32", "TimeTicks", "Gauge32")
( StorageType, TruthValue, DisplayString, TimeStamp, TextualConvention, RowStatus, TimeInterval, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "TruthValue", "DisplayString", "TimeStamp", "TextualConvention", "RowStatus", "TimeInterval")
mplsLdpStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 4)).setRevisions(("2004-06-03 00:00",))
if mibBuilder.loadTexts: mplsLdpStdMIB.setLastUpdated('200406030000Z')
if mibBuilder.loadTexts: mplsLdpStdMIB.setOrganization('Multiprotocol Label Switching (mpls)\n                       Working Group')
if mibBuilder.loadTexts: mplsLdpStdMIB.setContactInfo('Joan Cucchiara (jcucchiara@mindspring.com)\n              Marconi Communications, Inc.\n\n              Hans Sjostrand (hans@ipunplugged.com)\n              ipUnplugged\n\n              James V. Luciani (james_luciani@mindspring.com)\n              Marconi Communications, Inc.\n\n              Working Group Chairs:\n              George Swallow,   email: swallow@cisco.com\n              Loa Andersson,    email: loa@pi.se\n\n              MPLS Working Group, email: mpls@uu.net')
if mibBuilder.loadTexts: mplsLdpStdMIB.setDescription("Copyright (C) The Internet Society (2004). The\n             initial version of this MIB module was published\n             in RFC 3815. For full legal notices see the RFC\n             itself or see:\n             http://www.ietf.org/copyrights/ianamib.html\n\n             This MIB contains managed object definitions for the\n             'Multiprotocol Label Switching, Label Distribution\n             Protocol, LDP' document.")
mplsLdpNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 0))
mplsLdpObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 1))
mplsLdpConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 2))
mplsLdpLsrObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 1))
mplsLdpEntityObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2))
mplsLdpLsrId = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 1, 1), MplsLsrIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpLsrId.setDescription("The Label Switching Router's Identifier.")
mplsLdpLsrLoopDetectionCapable = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("none", 1), ("other", 2), ("hopCount", 3), ("pathVector", 4), ("hopCountAndPathVector", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpLsrLoopDetectionCapable.setDescription('A indication of whether this\n             Label Switching Router supports\n             loop detection.\n\n             none(1) -- Loop Detection is not supported\n                        on this LSR.\n\n             other(2) -- Loop Detection is supported but\n                         by a method other than those\n                         listed below.\n\n             hopCount(3) -- Loop Detection is supported by\n                            Hop Count only.\n\n             pathVector(4) -- Loop Detection is supported by\n                              Path Vector only.\n\n             hopCountAndPathVector(5) -- Loop Detection is\n                                  supported by both Hop Count\n                                  And Path Vector.\n\n             Since Loop Detection is determined during\n             Session Initialization, an individual session\n             may not be running with loop detection.  This\n             object simply gives an indication of whether or not the\n             LSR has the ability to support Loop Detection and\n             which types.')
mplsLdpEntityLastChange = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityLastChange.setDescription('The value of sysUpTime at the time of the most\n             recent addition or deletion of an entry\n             to/from the mplsLdpEntityTable/mplsLdpEntityStatsTable, or\n             the most recent change in value of any objects in the\n             mplsLdpEntityTable.\n             If no such changes have occurred since the last\n             re-initialization of the local management subsystem,\n             then this object contains a zero value.')
mplsLdpEntityIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 2), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityIndexNext.setDescription('This object contains an appropriate value to\n             be used for mplsLdpEntityIndex when creating\n             entries in the mplsLdpEntityTable. The value\n             0 indicates that no unassigned entries are\n             available.')
mplsLdpEntityTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3), )
if mibBuilder.loadTexts: mplsLdpEntityTable.setDescription('This table contains information about the\n             MPLS Label Distribution Protocol Entities which\n             exist on this Label Switching Router (LSR)\n             or Label Edge Router (LER).')
mplsLdpEntityEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"))
if mibBuilder.loadTexts: mplsLdpEntityEntry.setDescription('An entry in this table represents an LDP entity.\n              An entry can be created by a network administrator\n              or by an SNMP agent as instructed by LDP.')
mplsLdpEntityLdpId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 1), MplsLdpIdentifier())
if mibBuilder.loadTexts: mplsLdpEntityLdpId.setDescription('The LDP identifier.')
mplsLdpEntityIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 2), IndexInteger())
if mibBuilder.loadTexts: mplsLdpEntityIndex.setDescription("This index is used as a secondary index to uniquely\n             identify this row.  Before creating a row in this table,\n             the 'mplsLdpEntityIndexNext' object should be retrieved.\n             That value should be used for the value of this index\n             when creating a row in this table.  NOTE:  if a value\n             of zero (0) is retrieved, that indicates that no rows\n             can be created in this table at this time.\n\n             A secondary index (this object) is meaningful to some\n             but not all, LDP implementations.  For example\n             an LDP implementation which uses PPP would\n             use this index to differentiate PPP sub-links.\n\n             Another way to use this index is to give this the\n             value of ifIndex.  However, this is dependant\n             on the implementation.")
mplsLdpEntityProtocolVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityProtocolVersion.setDescription('The version number of the LDP protocol which will be\n            used in the session initialization message.\n    \n            Section 3.5.3 in the LDP Specification specifies\n            that the version of the LDP protocol is negotiated during\n            session establishment. The value of this object\n            represents the value that is sent in the initialization\n            message.')
mplsLdpEntityAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enable", 1), ("disable", 2),)).clone('enable')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityAdminStatus.setDescription("The administrative status of this LDP Entity.\n             If this object is changed from 'enable' to 'disable'\n             and this entity has already attempted to establish\n             contact with a Peer, then all contact with that\n             Peer is lost and all information from that Peer\n             needs to be removed from the MIB. (This implies\n             that the network management subsystem should clean\n             up any related entry in the mplsLdpPeerTable.  This\n             further implies that a 'tear-down' for that session\n             is issued and the session and all information related\n             to that session cease to exist).\n\n             At this point the operator is able to change values\n             which are related to this entity.\n\n             When the admin status is set back to 'enable', then\n             this Entity will attempt to establish a new session\n             with the Peer.")
mplsLdpEntityOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unknown", 1), ("enabled", 2), ("disabled", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityOperStatus.setDescription('The operational status of this LDP Entity.\n\n             The value of unknown(1) indicates that the\n             operational status cannot be determined at\n             this time.  The value of unknown should be\n             a transient condition before changing\n             to enabled(2) or disabled(3).')
mplsLdpEntityTcpPort = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 6), InetPortNumber().clone(646)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityTcpPort.setDescription('The TCP Port for\n             LDP.  The default value is the well-known\n             value of this port.')
mplsLdpEntityUdpDscPort = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 7), InetPortNumber().clone(646)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityUdpDscPort.setDescription('The UDP Discovery Port for\n             LDP.  The default value is the\n             well-known value for this port.')
mplsLdpEntityMaxPduLength = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 8), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(256,65535)).clone(4096)).setUnits('octets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityMaxPduLength.setDescription("The maximum PDU Length that is sent in\n            the Common Session Parameters of an Initialization\n            Message. According to the LDP Specification [RFC3036]\n            a value of 255 or less specifies the\n            default maximum length of 4096 octets, this is why\n            the value of this object starts at 256.  The operator\n            should explicitly choose the default value (i.e., 4096),\n            or some other value.\n\n            The receiving LSR MUST calculate the maximum PDU\n            length for the session by using the smaller of its and\n            its peer's proposals for Max PDU Length.")
mplsLdpEntityKeepAliveHoldTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 9), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(40)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityKeepAliveHoldTimer.setDescription('The 16-bit integer value which is the proposed keep\n             alive hold timer for this LDP Entity.')
mplsLdpEntityHelloHoldTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 10), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityHelloHoldTimer.setDescription("The 16-bit integer value which is the proposed Hello\n             hold timer for this LDP Entity. The Hello Hold time\n             in seconds.\n             An LSR maintains a record of Hellos received\n             from potential peers.  This object represents\n             the Hold Time in the Common Hello Parameters TLV of\n             the Hello Message.\n\n             A value of 0 is a default value and should be\n             interpretted in conjunction with the\n             mplsLdpEntityTargetPeer object.\n\n             If the value of this object is 0: if the value of the\n             mplsLdpEntityTargetPeer object is false(2), then this\n             specifies that the Hold Time's actual default value is\n             15 seconds (i.e., the default Hold time for Link Hellos\n             is 15 seconds).  Otherwise if the value of the\n             mplsLdpEntityTargetPeer object is true(1), then this\n             specifies that the Hold Time's actual default value is\n             45 seconds (i.e., the default Hold time for Targeted\n             Hellos is 45 seconds).\n\n             A value of 65535 means infinite (i.e., wait forever).\n\n             All other values represent the amount of time in\n             seconds to wait for a Hello Message.  Setting the\n             hold time to a value smaller than 15 is not\n             recommended, although not forbidden according\n             to RFC3036.")
mplsLdpEntityInitSessionThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 11), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,100)).clone(8)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityInitSessionThreshold.setDescription("When attempting to establish a session with\n             a given Peer, the given LDP Entity should\n             send out the SNMP notification,\n             'mplsLdpInitSessionThresholdExceeded', when\n             the number of Session Initialization messages\n             sent exceeds this threshold.\n\n             The notification is used to notify an\n             operator when this Entity and its Peer are\n             possibly engaged in an endless sequence\n             of messages as each NAKs the other's\n             Initialization messages with Error Notification\n             messages.  Setting this threshold which triggers\n             the notification is one way to notify the\n             operator.  The notification should be generated\n             each time this threshold is exceeded and\n             for every subsequent Initialization message\n             which is NAK'd with an Error Notification\n             message after this threshold is exceeded.\n\n             A value of 0 (zero) for this object\n             indicates that the threshold is infinity, thus\n             the SNMP notification will never be generated.")
mplsLdpEntityLabelDistMethod = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 12), MplsLabelDistributionMethod()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityLabelDistMethod.setDescription('For any given LDP session, the method of\n             label distribution must be specified.')
mplsLdpEntityLabelRetentionMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 13), MplsRetentionMode()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityLabelRetentionMode.setDescription('The LDP Entity can be configured to use either\n             conservative or liberal label retention mode.\n\n             If the value of this object is conservative(1)\n             then advertized label mappings are retained\n             only if they will be used to forward packets,\n             i.e., if label came from a valid next hop.\n\n             If the value of this object is liberal(2)\n             then all advertized label mappings are retained\n             whether they are from a valid next hop or not.')
mplsLdpEntityPathVectorLimit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 14), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityPathVectorLimit.setDescription("If the value of this object is 0 (zero) then\n             Loop Detection for Path Vectors is disabled.\n\n             Otherwise, if this object has a value greater than\n             zero, then Loop Dection for Path Vectors is enabled,\n             and the Path Vector Limit is this value.\n             Also, the value of the object,\n             'mplsLdpLsrLoopDetectionCapable', must be set to\n             either 'pathVector(4)' or 'hopCountAndPathVector(5)',\n             if this object has a value greater than 0 (zero),\n             otherwise it is ignored.")
mplsLdpEntityHopCountLimit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 15), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityHopCountLimit.setDescription("If the value of this object is 0 (zero),\n             then Loop Detection using Hop Counters is\n             disabled.\n\n             If the value of this object is greater than\n             0 (zero) then Loop Detection using Hop\n             Counters is enabled, and this object\n             specifies this Entity's maximum allowable\n             value for the Hop Count.\n             Also, the value of the object\n             mplsLdpLsrLoopDetectionCapable must be set\n             to either 'hopCount(3)' or\n             'hopCountAndPathVector(5)' if this object\n             has a value greater than 0 (zero), otherwise\n             it is ignored.")
mplsLdpEntityTransportAddrKind = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 16), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("interface", 1), ("loopback", 2),)).clone('loopback')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityTransportAddrKind.setDescription('This specifies whether the loopback or interface\n             address is to be used as the transport address\n             in the transport address TLV of the\n             hello message.\n\n             If the value is interface(1), then the IP\n             address of the interface from which hello\n             messages are sent is used as the transport\n             address in the hello message.\n\n             Otherwise, if the value is loopback(2), then the IP\n             address of the loopback interface is used as the\n             transport address in the hello message.')
mplsLdpEntityTargetPeer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 17), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityTargetPeer.setDescription('If this LDP entity uses targeted peer then set\n             this to true.')
mplsLdpEntityTargetPeerAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 18), InetAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityTargetPeerAddrType.setDescription('The type of the internetwork layer address used for\n             the Extended Discovery.  This object indicates how\n             the value of mplsLdpEntityTargetPeerAddr is to\n             be interpreted.')
mplsLdpEntityTargetPeerAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 19), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityTargetPeerAddr.setDescription('The value of the internetwork layer address\n             used for the Extended Discovery.  The value of\n             mplsLdpEntityTargetPeerAddrType specifies how\n             this address is to be interpreted.')
mplsLdpEntityLabelType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 20), MplsLdpLabelType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityLabelType.setDescription('Specifies the optional parameters for the LDP\n             Initialization Message.\n\n             If the value is generic(1) then no\n             optional parameters will be sent in\n             the LDP Initialization message associated\n             with this Entity.\n\n             If the value is atmParameters(2) then\n             a row must be created in the\n             mplsLdpEntityAtmTable, which\n             corresponds to this entry.\n\n             If the value is frameRelayParameters(3) then\n             a row must be created in the\n             mplsLdpEntityFrameRelayTable, which\n             corresponds to this entry.')
mplsLdpEntityDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 21), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion\n             at which any one or more of this entity's counters\n             suffered a discontinuity.  The relevant counters\n             are the specific instances associated with this\n             entity of any Counter32 object contained\n             in the 'mplsLdpEntityStatsTable'.  If no such\n             discontinuities have occurred since the last\n             re-initialization of the local management\n             subsystem, then this object contains a zero\n             value.")
mplsLdpEntityStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 22), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityStorageType.setDescription("The storage type for this conceptual row.\n             Conceptual rows having the value 'permanent(4)'\n             need not allow write-access to any columnar\n             objects in the row.")
mplsLdpEntityRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 3, 1, 23), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityRowStatus.setDescription("The status of this conceptual row.  All writable\n              objects in this row may be modified at any\n              time, however, as described in detail in\n              the section entitled, 'Changing Values After\n              Session Establishment', and again described\n              in the DESCRIPTION clause of the\n              mplsLdpEntityAdminStatus object, if a session\n              has been initiated with a Peer, changing objects\n              in this table will wreak havoc with the session\n              and interrupt traffic.  To repeat again:\n              the recommended procedure is to\n              set the mplsLdpEntityAdminStatus to down, thereby\n              explicitly causing a session to be torn down. Then,\n              change objects in this entry, then set\n              the mplsLdpEntityAdminStatus to enable,\n              which enables a new session to be initiated.")
mplsLdpEntityStatsTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4), )
if mibBuilder.loadTexts: mplsLdpEntityStatsTable.setDescription('This table is a read-only table which augments\n             the mplsLdpEntityTable.  The purpose of this\n             table is to keep statistical information about\n             the LDP Entities on the LSR.')
mplsLdpEntityStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1), )
mplsLdpEntityEntry.registerAugmentions(("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsEntry"))
mplsLdpEntityStatsEntry.setIndexNames(*mplsLdpEntityEntry.getIndexNames())
if mibBuilder.loadTexts: mplsLdpEntityStatsEntry.setDescription('A row in this table contains statistical information\n             about an LDP Entity.  Some counters contained in a\n             row are for fatal errors received during a former\n             LDP Session associated with this entry.  For example,\n             an LDP PDU received on a TCP connection during an\n             LDP Session contains a fatal error.  That\n             error is counted here, because the\n             session is terminated.\n\n             If the error is NOT fatal (i.e., the Session\n             remains), then the error is counted in the\n             mplsLdpSessionStatsEntry.')
mplsLdpEntityStatsSessionAttempts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsSessionAttempts.setDescription("A count of the Session Initialization messages\n             which were sent or received by this LDP Entity and\n             were NAK'd.   In other words, this counter counts\n             the number of session initializations that failed.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.")
mplsLdpEntityStatsSessionRejectedNoHelloErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsSessionRejectedNoHelloErrors.setDescription('A count of the Session Rejected/No Hello Error\n             Notification Messages sent or received by\n             this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsSessionRejectedAdErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsSessionRejectedAdErrors.setDescription('A count of the Session Rejected/Parameters\n             Advertisement Mode Error Notification Messages sent\n             or received by this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsSessionRejectedMaxPduErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsSessionRejectedMaxPduErrors.setDescription('A count of the Session Rejected/Parameters\n\n             Max Pdu Length Error Notification Messages sent\n             or received by this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsSessionRejectedLRErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsSessionRejectedLRErrors.setDescription('A count of the Session Rejected/Parameters\n             Label Range Notification Messages sent\n             or received by this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsBadLdpIdentifierErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsBadLdpIdentifierErrors.setDescription('This object counts the number of Bad LDP Identifier\n             Fatal Errors detected by the session(s)\n             (past and present) associated with this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsBadPduLengthErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsBadPduLengthErrors.setDescription('This object counts the number of Bad PDU Length\n             Fatal Errors detected by the session(s)\n             (past and present) associated with this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsBadMessageLengthErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsBadMessageLengthErrors.setDescription('This object counts the number of Bad Message\n             Length Fatal Errors detected by the session(s)\n             (past and present) associated with this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsBadTlvLengthErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsBadTlvLengthErrors.setDescription('This object counts the number of Bad TLV\n             Length Fatal Errors detected by the session(s)\n             (past and present) associated with this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsMalformedTlvValueErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsMalformedTlvValueErrors.setDescription('This object counts the number of Malformed TLV\n             Value Fatal Errors detected by the session(s)\n             (past and present) associated with this\n             LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsKeepAliveTimerExpErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsKeepAliveTimerExpErrors.setDescription('This object counts the number of Session Keep Alive\n             Timer Expired Errors detected by the session(s)\n             (past and present) associated with this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsShutdownReceivedNotifications = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsShutdownReceivedNotifications.setDescription('This object counts the number of Shutdown Notifications\n             received related to session(s) (past and present)\n             associated with this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpEntityStatsShutdownSentNotifications = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 2, 4, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityStatsShutdownSentNotifications.setDescription('This object counts the number of Shutdown Notfications\n             sent related to session(s) (past and present) associated\n             with this LDP Entity.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpEntityDiscontinuityTime.')
mplsLdpSessionObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3))
mplsLdpPeerLastChange = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpPeerLastChange.setDescription('The value of sysUpTime at the time of the most\n             recent addition or deletion to/from the\n             mplsLdpPeerTable/mplsLdpSessionTable.')
mplsLdpPeerTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 2), )
if mibBuilder.loadTexts: mplsLdpPeerTable.setDescription('Information about LDP peers known by Entities in\n             the mplsLdpEntityTable.  The information in this table\n             is based on information from the Entity-Peer interaction\n             during session initialization but is not appropriate\n             for the mplsLdpSessionTable, because objects in this\n             table may or may not be used in session establishment.')
mplsLdpPeerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 2, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"), (0, "MPLS-LDP-STD-MIB", "mplsLdpPeerLdpId"))
if mibBuilder.loadTexts: mplsLdpPeerEntry.setDescription('Information about a single Peer which is related\n             to a Session.  This table is augmented by\n             the mplsLdpSessionTable.')
mplsLdpPeerLdpId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 2, 1, 1), MplsLdpIdentifier())
if mibBuilder.loadTexts: mplsLdpPeerLdpId.setDescription('The LDP identifier of this LDP Peer.')
mplsLdpPeerLabelDistMethod = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 2, 1, 2), MplsLabelDistributionMethod()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpPeerLabelDistMethod.setDescription('For any given LDP session, the method of\n             label distribution must be specified.')
mplsLdpPeerPathVectorLimit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpPeerPathVectorLimit.setDescription('If the value of this object is 0 (zero) then\n             Loop Dection for Path Vectors for this Peer\n             is disabled.\n\n             Otherwise, if this object has a value greater than\n             zero, then Loop Dection for Path  Vectors for this\n             Peer is enabled and the Path Vector Limit is this value.')
mplsLdpPeerTransportAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 2, 1, 4), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpPeerTransportAddrType.setDescription("The type of the Internet address for the\n             mplsLdpPeerTransportAddr object.  The LDP\n             specification describes this as being either\n             an IPv4 Transport Address or IPv6 Transport\n             Address which is used in opening the LDP session's\n             TCP connection, or if the optional TLV is not\n             present, then this is the IPv4/IPv6 source\n             address for the UPD packet carrying the Hellos.\n\n             This object specifies how the value of the\n             mplsLdpPeerTransportAddr object should be\n             interpreted.")
mplsLdpPeerTransportAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 2, 1, 5), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpPeerTransportAddr.setDescription('The Internet address advertised by the peer\n             in the Hello Message or the Hello source address.\n\n             The type of this address is specified by the\n             value of the mplsLdpPeerTransportAddrType\n             object.')
mplsLdpSessionTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3), )
if mibBuilder.loadTexts: mplsLdpSessionTable.setDescription('A table of Sessions between the LDP Entities\n             and LDP Peers.  This table AUGMENTS the\n             mplsLdpPeerTable.  Each row in this table\n             represents a single session.')
mplsLdpSessionEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3, 1), )
mplsLdpPeerEntry.registerAugmentions(("MPLS-LDP-STD-MIB", "mplsLdpSessionEntry"))
mplsLdpSessionEntry.setIndexNames(*mplsLdpPeerEntry.getIndexNames())
if mibBuilder.loadTexts: mplsLdpSessionEntry.setDescription("An entry in this table represents information on a\n             single session between an LDP Entity and LDP Peer.\n             The information contained in a row is read-only.\n\n             Please note:  the Path Vector Limit for the\n             Session is the value which is configured in\n             the corresponding mplsLdpEntityEntry. The\n             Peer's Path Vector Limit is in the\n             mplsLdpPeerPathVectorLimit object in the\n             mplsLdpPeerTable.\n\n             Values which may differ from those configured are\n             noted in the objects of this table, the\n             mplsLdpAtmSessionTable and the\n             mplsLdpFrameRelaySessionTable. A value will\n             differ if it was negotiated between the\n             Entity and the Peer.  Values may or may not\n             be negotiated.  For example, if the values\n             are the same then no negotiation takes place.\n             If they are negotiated, then they may differ.")
mplsLdpSessionStateLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionStateLastChange.setDescription('The value of sysUpTime at the time this\n             Session entered its current state as\n             denoted by the mplsLdpSessionState\n             object.')
mplsLdpSessionState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("nonexistent", 1), ("initialized", 2), ("openrec", 3), ("opensent", 4), ("operational", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionState.setDescription('The current state of the session, all of the\n             states 1 to 5 are based on the state machine\n             for session negotiation behavior.')
mplsLdpSessionRole = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unknown", 1), ("active", 2), ("passive", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionRole.setDescription("During session establishment the LSR/LER takes either\n             the active role or the passive role based on address\n             comparisons.  This object indicates whether this LSR/LER\n             was behaving in an active role or passive role during\n             this session's establishment.\n\n             The value of unknown(1), indicates that the role is not\n             able to be determined at the present time.")
mplsLdpSessionProtocolVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionProtocolVersion.setDescription('The version of the LDP Protocol which\n             this session is using.  This is the version of\n             the LDP protocol which has been negotiated\n             during session initialization.')
mplsLdpSessionKeepAliveHoldTimeRem = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3, 1, 5), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionKeepAliveHoldTimeRem.setDescription('The keep alive hold time remaining for\n             this session.')
mplsLdpSessionKeepAliveTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3, 1, 6), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionKeepAliveTime.setDescription("The negotiated KeepAlive Time which\n                represents the amount of seconds between\n                keep alive messages.  The\n                mplsLdpEntityKeepAliveHoldTimer\n                related to this Session is the\n                value that was proposed as the\n                KeepAlive Time for this session.\n\n                This value is negotiated during\n                session initialization between\n                the entity's proposed value\n                (i.e., the value configured in\n                mplsLdpEntityKeepAliveHoldTimer)\n                and the peer's proposed\n                KeepAlive Hold Timer value.\n                This value is the smaller\n                of the two proposed values.")
mplsLdpSessionMaxPduLength = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3, 1, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionMaxPduLength.setDescription('The value of maximum allowable length for LDP PDUs for\n                this session.  This value may have been negotiated\n                during the Session Initialization.  This object is\n                related to the mplsLdpEntityMaxPduLength object.  The\n                mplsLdpEntityMaxPduLength object specifies the requested\n                LDP PDU length, and this object reflects the negotiated\n                LDP PDU length between the Entity and\n                the Peer.')
mplsLdpSessionDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 3, 1, 8), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion\n             at which any one or more of this session's counters\n             suffered a discontinuity.  The relevant counters are\n             the specific instances associated with this session\n             of any Counter32 object contained in the\n             mplsLdpSessionStatsTable.\n\n             The initial value of this object is the value of\n             sysUpTime when the entry was created in this table.\n\n             Also, a command generator can distinguish when a session\n             between a given Entity and Peer goes away and a new\n             session is established.  This value would change and\n             thus indicate to the command generator that this is a\n             different session.")
mplsLdpSessionStatsTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 4), )
if mibBuilder.loadTexts: mplsLdpSessionStatsTable.setDescription('A table of statistics for Sessions between\n             LDP Entities and LDP Peers.  This table AUGMENTS\n             the mplsLdpPeerTable.')
mplsLdpSessionStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 4, 1), )
mplsLdpPeerEntry.registerAugmentions(("MPLS-LDP-STD-MIB", "mplsLdpSessionStatsEntry"))
mplsLdpSessionStatsEntry.setIndexNames(*mplsLdpPeerEntry.getIndexNames())
if mibBuilder.loadTexts: mplsLdpSessionStatsEntry.setDescription('An entry in this table represents statistical\n             information on a single session between an LDP\n             Entity and LDP Peer.')
mplsLdpSessionStatsUnknownMesTypeErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 4, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionStatsUnknownMesTypeErrors.setDescription('This object counts the number of Unknown Message Type\n             Errors detected by this LSR/LER during this session.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpSessionDiscontinuityTime.')
mplsLdpSessionStatsUnknownTlvErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 4, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionStatsUnknownTlvErrors.setDescription('This object counts the number of Unknown TLV Errors\n             detected by this LSR/LER during this session.\n\n             Discontinuities in the value of this counter can occur\n             at re-initialization of the management system, and at\n             other times as indicated by the value of\n             mplsLdpSessionDiscontinuityTime.')
mplsLdpHelloAdjacencyObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 5))
mplsLdpHelloAdjacencyTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 5, 1), )
if mibBuilder.loadTexts: mplsLdpHelloAdjacencyTable.setDescription('A table of Hello Adjacencies for Sessions.')
mplsLdpHelloAdjacencyEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 5, 1, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"), (0, "MPLS-LDP-STD-MIB", "mplsLdpPeerLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpHelloAdjacencyIndex"))
if mibBuilder.loadTexts: mplsLdpHelloAdjacencyEntry.setDescription('Each row represents a single LDP Hello Adjacency.\n             An LDP Session can have one or more Hello\n             Adjacencies.')
mplsLdpHelloAdjacencyIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 5, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: mplsLdpHelloAdjacencyIndex.setDescription('An identifier for this specific adjacency.')
mplsLdpHelloAdjacencyHoldTimeRem = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 5, 1, 1, 2), TimeInterval()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpHelloAdjacencyHoldTimeRem.setDescription("If the value of this object is 65535,\n             this means that the hold time is infinite\n             (i.e., wait forever).\n\n             Otherwise, the time remaining for\n             this Hello Adjacency to receive its\n             next Hello Message.\n\n             This interval will change when the 'next'\n             Hello Message which corresponds to this\n             Hello Adjacency is received unless it\n             is infinite.")
mplsLdpHelloAdjacencyHoldTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 5, 1, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpHelloAdjacencyHoldTime.setDescription('The Hello hold time which is negotiated between\n             the Entity and the Peer.  The entity associated\n             with this Hello Adjacency issues a proposed\n             Hello Hold Time value in the\n             mplsLdpEntityHelloHoldTimer object.  The peer\n             also proposes a value and this object represents\n             the negotiated value.\n\n             A value of 0 means the default,\n             which is 15 seconds for Link Hellos\n             and 45 seconds for Targeted Hellos.\n             A value of 65535 indicates an\n             infinite hold time.')
mplsLdpHelloAdjacencyType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 5, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("link", 1), ("targeted", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpHelloAdjacencyType.setDescription("This adjacency is the result of a 'link'\n             hello if the value of this object is link(1).\n             Otherwise, it is a result of a 'targeted'\n             hello, targeted(2).")
mplsInSegmentLdpLspTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 6), )
if mibBuilder.loadTexts: mplsInSegmentLdpLspTable.setDescription("A table of LDP LSP's which\n             map to the mplsInSegmentTable in the\n             MPLS-LSR-STD-MIB module.")
mplsInSegmentLdpLspEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 6, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"), (0, "MPLS-LDP-STD-MIB", "mplsLdpPeerLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsInSegmentLdpLspIndex"))
if mibBuilder.loadTexts: mplsInSegmentLdpLspEntry.setDescription("An entry in this table represents information\n             on a single LDP LSP which is represented by\n             a session's index triple (mplsLdpEntityLdpId,\n             mplsLdpEntityIndex, mplsLdpPeerLdpId) AND the\n             index for the mplsInSegmentTable\n             (mplsInSegmentLdpLspLabelIndex) from the\n             MPLS-LSR-STD-MIB.\n\n             The information contained in a row is read-only.")
mplsInSegmentLdpLspIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 6, 1, 1), MplsIndexType())
if mibBuilder.loadTexts: mplsInSegmentLdpLspIndex.setDescription("This contains the same value as the\n             mplsInSegmentIndex in the\n             MPLS-LSR-STD-MIB's mplsInSegmentTable.")
mplsInSegmentLdpLspLabelType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 6, 1, 2), MplsLdpLabelType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentLdpLspLabelType.setDescription('The Layer 2 Label Type.')
mplsInSegmentLdpLspType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 6, 1, 3), MplsLspType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentLdpLspType.setDescription('The type of LSP connection.')
mplsOutSegmentLdpLspTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 7), )
if mibBuilder.loadTexts: mplsOutSegmentLdpLspTable.setDescription("A table of LDP LSP's which\n             map to the mplsOutSegmentTable in the\n            MPLS-LSR-STD-MIB.")
mplsOutSegmentLdpLspEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 7, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"), (0, "MPLS-LDP-STD-MIB", "mplsLdpPeerLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsOutSegmentLdpLspIndex"))
if mibBuilder.loadTexts: mplsOutSegmentLdpLspEntry.setDescription("An entry in this table represents information\n             on a single LDP LSP which is represented by\n             a session's index triple (mplsLdpEntityLdpId,\n             mplsLdpEntityIndex, mplsLdpPeerLdpId) AND the\n             index (mplsOutSegmentLdpLspIndex)\n             for the mplsOutSegmentTable.\n\n             The information contained in a row is read-only.")
mplsOutSegmentLdpLspIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 7, 1, 1), MplsIndexType())
if mibBuilder.loadTexts: mplsOutSegmentLdpLspIndex.setDescription("This contains the same value as the\n             mplsOutSegmentIndex in the\n             MPLS-LSR-STD-MIB's mplsOutSegmentTable.")
mplsOutSegmentLdpLspLabelType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 7, 1, 2), MplsLdpLabelType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentLdpLspLabelType.setDescription('The Layer 2 Label Type.')
mplsOutSegmentLdpLspType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 7, 1, 3), MplsLspType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentLdpLspType.setDescription('The type of LSP connection.')
mplsFecObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8))
mplsFecLastChange = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsFecLastChange.setDescription('The value of sysUpTime at the time of the most\n             recent addition/deletion of an entry\n             to/from the mplsLdpFectTable or\n             the most recent change in values to any objects\n             in the mplsLdpFecTable.\n\n             If no such changes have occurred since the last\n             re-initialization of the local management subsystem,\n             then this object contains a zero value.')
mplsFecIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 2), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsFecIndexNext.setDescription('This object contains an appropriate value to\n             be used for mplsFecIndex when creating\n             entries in the mplsFecTable. The value\n             0 indicates that no unassigned entries are\n             available.')
mplsFecTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 3), )
if mibBuilder.loadTexts: mplsFecTable.setDescription('This table represents the FEC\n             (Forwarding Equivalence Class)\n             Information associated with an LSP.')
mplsFecEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 3, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsFecIndex"))
if mibBuilder.loadTexts: mplsFecEntry.setDescription('Each row represents a single FEC Element.')
mplsFecIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 3, 1, 1), IndexInteger())
if mibBuilder.loadTexts: mplsFecIndex.setDescription('The index which uniquely identifies this entry.')
mplsFecType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 3, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("prefix", 1), ("hostAddress", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsFecType.setDescription("The type of the FEC.  If the value of this object\n             is 'prefix(1)' then the FEC type described by this\n             row is an address prefix.\n\n             If the value of this object is 'hostAddress(2)' then\n             the FEC type described by this row is a host address.")
mplsFecAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 3, 1, 4), InetAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsFecAddrType.setDescription('The value of this object is the type of the\n             Internet address.  The value of this object,\n             decides how the value of the mplsFecAddr object\n             is interpreted.')
mplsFecAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 3, 1, 5), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsFecAddr.setDescription("The value of this object is interpreted based\n             on the value of the 'mplsFecAddrType' object.\n\n             This address is then further interpretted as\n             an being used with the address prefix,\n             or as the host address.  This further interpretation\n             is indicated by the 'mplsFecType' object.\n             In other words, the FEC element is populated\n             according to the Prefix FEC Element value encoding, or\n             the Host Address FEC Element encoding.")
mplsFecAddrPrefixLength = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 3, 1, 3), InetAddressPrefixLength()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsFecAddrPrefixLength.setDescription("If the value of the 'mplsFecType' is 'hostAddress(2)'\n             then this object is undefined.\n\n             If the value of 'mplsFecType' is 'prefix(1)'\n             then the value of this object is the length in\n             bits of the address prefix represented by\n             'mplsFecAddr', or zero.  If the value of this\n             object is zero, this indicates that the\n             prefix matches all addresses.  In this case the\n             address prefix MUST also be zero (i.e., 'mplsFecAddr'\n             should have the value of zero.)")
mplsFecStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 3, 1, 6), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsFecStorageType.setDescription("The storage type for this conceptual row.\n             Conceptual rows having the value 'permanent(4)'\n             need not allow write-access to any columnar\n             objects in the row.")
mplsFecRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 8, 3, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsFecRowStatus.setDescription("The status of this conceptual row.  If the value of this\n             object is 'active(1)', then none of the writable objects\n             of this entry can be modified, except to set this object\n             to 'destroy(6)'.\n\n             NOTE: if this row is being referenced by any entry in\n             the mplsLdpLspFecTable, then a request to destroy\n             this row, will result in an inconsistentValue error.")
mplsLdpLspFecLastChange = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 9), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpLspFecLastChange.setDescription('The value of sysUpTime at the time of the most\n             recent addition/deletion of an entry\n             to/from the mplsLdpLspFecTable or\n             the most recent change in values to any objects in the\n             mplsLdpLspFecTable.\n\n             If no such changes have occurred since the last\n             re-initialization of the local management subsystem,\n             then this object contains a zero value.')
mplsLdpLspFecTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 10), )
if mibBuilder.loadTexts: mplsLdpLspFecTable.setDescription('A table which shows the relationship between\n           LDP LSPs and FECs.  Each row represents\n           a single LDP LSP to FEC association.')
mplsLdpLspFecEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 10, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"), (0, "MPLS-LDP-STD-MIB", "mplsLdpPeerLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpLspFecSegment"), (0, "MPLS-LDP-STD-MIB", "mplsLdpLspFecSegmentIndex"), (0, "MPLS-LDP-STD-MIB", "mplsLdpLspFecIndex"))
if mibBuilder.loadTexts: mplsLdpLspFecEntry.setDescription('An entry represents a LDP LSP\n           to FEC association.')
mplsLdpLspFecSegment = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 10, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("inSegment", 1), ("outSegment", 2),)))
if mibBuilder.loadTexts: mplsLdpLspFecSegment.setDescription('If the value is inSegment(1), then this\n            indicates that the following index,\n            mplsLdpLspFecSegmentIndex, contains the same\n            value as the mplsInSegmentLdpLspIndex.\n\n            Otherwise, if the value of this object is\n            outSegment(2),  then this\n            indicates that following index,\n            mplsLdpLspFecSegmentIndex, contains the same\n            value as the mplsOutSegmentLdpLspIndex.')
mplsLdpLspFecSegmentIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 10, 1, 2), MplsIndexType())
if mibBuilder.loadTexts: mplsLdpLspFecSegmentIndex.setDescription('This index is interpretted by using the value\n            of the mplsLdpLspFecSegment.\n\n            If the mplsLdpLspFecSegment is inSegment(1),\n            then this index has the same value as\n            mplsInSegmentLdpLspIndex.\n\n            If the mplsLdpLspFecSegment is outSegment(2),\n            then this index has the same value as\n            mplsOutSegmentLdpLspIndex.')
mplsLdpLspFecIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 10, 1, 3), IndexInteger())
if mibBuilder.loadTexts: mplsLdpLspFecIndex.setDescription('This index identifies the FEC entry in the\n             mplsFecTable associated with this session.\n             In other words, the value of this index\n             is the same as the value of the mplsFecIndex\n             that denotes the FEC associated with this\n             Session.')
mplsLdpLspFecStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 10, 1, 4), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpLspFecStorageType.setDescription("The storage type for this conceptual row.\n            Conceptual rows having the value 'permanent(4)'\n            need not allow write-access to any columnar\n            objects in the row.")
mplsLdpLspFecRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 10, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpLspFecRowStatus.setDescription("The status of this conceptual row.  If the\n             value of this object is 'active(1)', then\n             none of the writable objects of this entry\n             can be modified.\n\n             The Agent should delete this row when\n             the session ceases to exist.  If an\n             operator wants to associate the session with\n             a different FEC, the recommended\n             procedure is (as described in detail in the section\n             entitled, 'Changing Values After Session\n             Establishment', and again described in the\n             DESCRIPTION clause of the\n             mplsLdpEntityAdminStatus object)\n             is to set the mplsLdpEntityAdminStatus to\n             down, thereby explicitly causing a session\n             to be torn down. This will also\n             cause this entry to be deleted.\n\n             Then, set the mplsLdpEntityAdminStatus\n             to enable which enables a new session to be initiated.\n             Once the session is initiated, an entry may be\n             added to this table to associate the new session\n             with a FEC.")
mplsLdpSessionPeerAddrTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 11), )
if mibBuilder.loadTexts: mplsLdpSessionPeerAddrTable.setDescription("This table 'extends' the mplsLdpSessionTable.\n             This table is used to store Label Address Information\n             from Label Address Messages received by this LSR from\n             Peers.  This table is read-only and should be updated\n             when Label Withdraw Address Messages are received, i.e.,\n             Rows should be deleted as appropriate.\n\n             NOTE:  since more than one address may be contained\n             in a Label Address Message, this table 'sparse augments',\n             the mplsLdpSessionTable's information.")
mplsLdpSessionPeerAddrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 11, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"), (0, "MPLS-LDP-STD-MIB", "mplsLdpPeerLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpSessionPeerAddrIndex"))
if mibBuilder.loadTexts: mplsLdpSessionPeerAddrEntry.setDescription("An entry in this table represents information on\n             a session's single next hop address which was\n             advertised in an Address Message from the LDP peer.\n             The information contained in a row is read-only.")
mplsLdpSessionPeerAddrIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 11, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: mplsLdpSessionPeerAddrIndex.setDescription('An index which uniquely identifies this entry within\n             a given session.')
mplsLdpSessionPeerNextHopAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 11, 1, 2), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionPeerNextHopAddrType.setDescription('The internetwork layer address type of this Next Hop\n             Address as specified in the Label Address Message\n             associated with this Session. The value of this\n             object indicates how to interpret the value of\n             mplsLdpSessionPeerNextHopAddr.')
mplsLdpSessionPeerNextHopAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 4, 1, 3, 11, 1, 3), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpSessionPeerNextHopAddr.setDescription('The next hop address.  The type of this address\n             is specified by the value of the\n             mplsLdpSessionPeerNextHopAddrType.')
mplsLdpInitSessionThresholdExceeded = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 4, 0, 1)).setObjects(*(("MPLS-LDP-STD-MIB", "mplsLdpEntityInitSessionThreshold"),))
if mibBuilder.loadTexts: mplsLdpInitSessionThresholdExceeded.setDescription("This notification is generated when the value of\n             the 'mplsLdpEntityInitSessionThreshold' object\n             is not zero, and the number of Session\n             Initialization messages exceeds the value\n             of the 'mplsLdpEntityInitSessionThreshold' object.")
mplsLdpPathVectorLimitMismatch = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 4, 0, 2)).setObjects(*(("MPLS-LDP-STD-MIB", "mplsLdpEntityPathVectorLimit"), ("MPLS-LDP-STD-MIB", "mplsLdpPeerPathVectorLimit"),))
if mibBuilder.loadTexts: mplsLdpPathVectorLimitMismatch.setDescription("This notification is sent when the\n             'mplsLdpEntityPathVectorLimit' does NOT match\n             the value of the 'mplsLdpPeerPathVectorLimit' for\n             a specific Entity.")
mplsLdpSessionUp = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 4, 0, 3)).setObjects(*(("MPLS-LDP-STD-MIB", "mplsLdpSessionState"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionDiscontinuityTime"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionStatsUnknownMesTypeErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionStatsUnknownTlvErrors"),))
if mibBuilder.loadTexts: mplsLdpSessionUp.setDescription("If this notification is sent when the\n             value of 'mplsLdpSessionState' enters\n             the 'operational(5)' state.")
mplsLdpSessionDown = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 4, 0, 4)).setObjects(*(("MPLS-LDP-STD-MIB", "mplsLdpSessionState"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionDiscontinuityTime"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionStatsUnknownMesTypeErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionStatsUnknownTlvErrors"),))
if mibBuilder.loadTexts: mplsLdpSessionDown.setDescription("This notification is sent when the\n             value of 'mplsLdpSessionState' leaves\n             the 'operational(5)' state.")
mplsLdpGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 2, 1))
mplsLdpCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 4, 2, 2))
mplsLdpModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 4, 2, 2, 1)).setObjects(*(("MPLS-LDP-STD-MIB", "mplsLdpGeneralGroup"), ("MPLS-LDP-STD-MIB", "mplsLdpNotificationsGroup"), ("MPLS-LDP-STD-MIB", "mplsLdpLspGroup"),))
if mibBuilder.loadTexts: mplsLdpModuleFullCompliance.setDescription('The Module is implemented with support\n             for read-create and read-write.  In other\n             words, both monitoring and configuration\n             are available when using this MODULE-COMPLIANCE.')
mplsLdpModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 4, 2, 2, 2)).setObjects(*(("MPLS-LDP-STD-MIB", "mplsLdpGeneralGroup"), ("MPLS-LDP-STD-MIB", "mplsLdpNotificationsGroup"), ("MPLS-LDP-STD-MIB", "mplsLdpLspGroup"),))
if mibBuilder.loadTexts: mplsLdpModuleReadOnlyCompliance.setDescription('The Module is implemented with support\n             for read-only.  In other words, only monitoring\n             is available by implementing this MODULE-COMPLIANCE.')
mplsLdpGeneralGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 4, 2, 1, 1)).setObjects(*(("MPLS-LDP-STD-MIB", "mplsLdpLsrId"), ("MPLS-LDP-STD-MIB", "mplsLdpLsrLoopDetectionCapable"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityLastChange"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityIndexNext"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityProtocolVersion"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityAdminStatus"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityOperStatus"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityTcpPort"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityUdpDscPort"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityMaxPduLength"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityKeepAliveHoldTimer"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityHelloHoldTimer"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityInitSessionThreshold"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityLabelDistMethod"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityLabelRetentionMode"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityPathVectorLimit"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityHopCountLimit"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityTransportAddrKind"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityTargetPeer"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityTargetPeerAddrType"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityTargetPeerAddr"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityLabelType"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityDiscontinuityTime"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStorageType"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityRowStatus"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsSessionAttempts"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsSessionRejectedNoHelloErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsSessionRejectedAdErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsSessionRejectedMaxPduErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsSessionRejectedLRErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsBadLdpIdentifierErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsBadPduLengthErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsBadMessageLengthErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsBadTlvLengthErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsMalformedTlvValueErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsKeepAliveTimerExpErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsShutdownReceivedNotifications"), ("MPLS-LDP-STD-MIB", "mplsLdpEntityStatsShutdownSentNotifications"), ("MPLS-LDP-STD-MIB", "mplsLdpPeerLastChange"), ("MPLS-LDP-STD-MIB", "mplsLdpPeerLabelDistMethod"), ("MPLS-LDP-STD-MIB", "mplsLdpPeerPathVectorLimit"), ("MPLS-LDP-STD-MIB", "mplsLdpPeerTransportAddrType"), ("MPLS-LDP-STD-MIB", "mplsLdpPeerTransportAddr"), ("MPLS-LDP-STD-MIB", "mplsLdpHelloAdjacencyHoldTimeRem"), ("MPLS-LDP-STD-MIB", "mplsLdpHelloAdjacencyHoldTime"), ("MPLS-LDP-STD-MIB", "mplsLdpHelloAdjacencyType"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionStateLastChange"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionState"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionRole"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionProtocolVersion"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionKeepAliveHoldTimeRem"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionKeepAliveTime"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionMaxPduLength"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionDiscontinuityTime"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionStatsUnknownMesTypeErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionStatsUnknownTlvErrors"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionPeerNextHopAddrType"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionPeerNextHopAddr"), ("MPLS-LDP-STD-MIB", "mplsFecLastChange"), ("MPLS-LDP-STD-MIB", "mplsFecIndexNext"), ("MPLS-LDP-STD-MIB", "mplsFecType"), ("MPLS-LDP-STD-MIB", "mplsFecAddrType"), ("MPLS-LDP-STD-MIB", "mplsFecAddr"), ("MPLS-LDP-STD-MIB", "mplsFecAddrPrefixLength"), ("MPLS-LDP-STD-MIB", "mplsFecStorageType"), ("MPLS-LDP-STD-MIB", "mplsFecRowStatus"),))
if mibBuilder.loadTexts: mplsLdpGeneralGroup.setDescription('Objects that apply to all MPLS LDP implementations.')
mplsLdpLspGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 4, 2, 1, 2)).setObjects(*(("MPLS-LDP-STD-MIB", "mplsInSegmentLdpLspLabelType"), ("MPLS-LDP-STD-MIB", "mplsInSegmentLdpLspType"), ("MPLS-LDP-STD-MIB", "mplsOutSegmentLdpLspLabelType"), ("MPLS-LDP-STD-MIB", "mplsOutSegmentLdpLspType"), ("MPLS-LDP-STD-MIB", "mplsLdpLspFecLastChange"), ("MPLS-LDP-STD-MIB", "mplsLdpLspFecStorageType"), ("MPLS-LDP-STD-MIB", "mplsLdpLspFecRowStatus"),))
if mibBuilder.loadTexts: mplsLdpLspGroup.setDescription('These objects are for LDP implementations\n             which interface to the Label Information Base (LIB)\n             in the MPLS-LSR-STD-MIB.  The LIB is\n             represented in the mplsInSegmentTable,\n             mplsOutSegmentTable and mplsXCTable.')
mplsLdpNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 166, 4, 2, 1, 3)).setObjects(*(("MPLS-LDP-STD-MIB", "mplsLdpInitSessionThresholdExceeded"), ("MPLS-LDP-STD-MIB", "mplsLdpPathVectorLimitMismatch"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionUp"), ("MPLS-LDP-STD-MIB", "mplsLdpSessionDown"),))
if mibBuilder.loadTexts: mplsLdpNotificationsGroup.setDescription('The notification for an MPLS LDP implementation.')
mibBuilder.exportSymbols("MPLS-LDP-STD-MIB", mplsLdpPeerEntry=mplsLdpPeerEntry, mplsLdpPeerTransportAddr=mplsLdpPeerTransportAddr, mplsLdpEntityLabelRetentionMode=mplsLdpEntityLabelRetentionMode, mplsLdpEntityLabelDistMethod=mplsLdpEntityLabelDistMethod, mplsLdpPeerLdpId=mplsLdpPeerLdpId, mplsLdpSessionObjects=mplsLdpSessionObjects, mplsLdpSessionPeerAddrEntry=mplsLdpSessionPeerAddrEntry, mplsLdpPeerTransportAddrType=mplsLdpPeerTransportAddrType, mplsLdpEntityStorageType=mplsLdpEntityStorageType, mplsLdpEntityHelloHoldTimer=mplsLdpEntityHelloHoldTimer, mplsLdpModuleFullCompliance=mplsLdpModuleFullCompliance, mplsLdpEntityStatsSessionRejectedLRErrors=mplsLdpEntityStatsSessionRejectedLRErrors, mplsLdpHelloAdjacencyHoldTimeRem=mplsLdpHelloAdjacencyHoldTimeRem, mplsLdpEntityLastChange=mplsLdpEntityLastChange, mplsInSegmentLdpLspIndex=mplsInSegmentLdpLspIndex, mplsLdpPeerTable=mplsLdpPeerTable, mplsLdpEntityPathVectorLimit=mplsLdpEntityPathVectorLimit, mplsLdpPeerPathVectorLimit=mplsLdpPeerPathVectorLimit, mplsOutSegmentLdpLspType=mplsOutSegmentLdpLspType, mplsLdpEntityTargetPeer=mplsLdpEntityTargetPeer, mplsLdpEntityStatsSessionAttempts=mplsLdpEntityStatsSessionAttempts, mplsLdpLspFecStorageType=mplsLdpLspFecStorageType, mplsLdpHelloAdjacencyTable=mplsLdpHelloAdjacencyTable, mplsLdpEntityLabelType=mplsLdpEntityLabelType, mplsLdpSessionDown=mplsLdpSessionDown, mplsLdpSessionUp=mplsLdpSessionUp, mplsLdpLsrLoopDetectionCapable=mplsLdpLsrLoopDetectionCapable, mplsLdpEntityProtocolVersion=mplsLdpEntityProtocolVersion, mplsInSegmentLdpLspLabelType=mplsInSegmentLdpLspLabelType, mplsLdpHelloAdjacencyIndex=mplsLdpHelloAdjacencyIndex, mplsFecLastChange=mplsFecLastChange, mplsLdpSessionState=mplsLdpSessionState, mplsLdpSessionProtocolVersion=mplsLdpSessionProtocolVersion, mplsLdpEntityIndexNext=mplsLdpEntityIndexNext, mplsLdpSessionKeepAliveHoldTimeRem=mplsLdpSessionKeepAliveHoldTimeRem, mplsLdpSessionStatsTable=mplsLdpSessionStatsTable, mplsLdpSessionTable=mplsLdpSessionTable, mplsFecType=mplsFecType, mplsLdpSessionStateLastChange=mplsLdpSessionStateLastChange, mplsInSegmentLdpLspType=mplsInSegmentLdpLspType, mplsLdpGeneralGroup=mplsLdpGeneralGroup, mplsLdpStdMIB=mplsLdpStdMIB, mplsLdpSessionPeerNextHopAddrType=mplsLdpSessionPeerNextHopAddrType, mplsLdpInitSessionThresholdExceeded=mplsLdpInitSessionThresholdExceeded, mplsLdpEntityObjects=mplsLdpEntityObjects, mplsLdpEntityTable=mplsLdpEntityTable, mplsLdpLspGroup=mplsLdpLspGroup, mplsLdpEntityStatsBadPduLengthErrors=mplsLdpEntityStatsBadPduLengthErrors, mplsLdpEntityTargetPeerAddr=mplsLdpEntityTargetPeerAddr, mplsLdpEntityHopCountLimit=mplsLdpEntityHopCountLimit, mplsLdpEntityEntry=mplsLdpEntityEntry, mplsLdpSessionMaxPduLength=mplsLdpSessionMaxPduLength, mplsFecRowStatus=mplsFecRowStatus, mplsLdpHelloAdjacencyObjects=mplsLdpHelloAdjacencyObjects, mplsLdpHelloAdjacencyType=mplsLdpHelloAdjacencyType, mplsLdpEntityStatsBadTlvLengthErrors=mplsLdpEntityStatsBadTlvLengthErrors, mplsFecTable=mplsFecTable, mplsLdpSessionPeerAddrIndex=mplsLdpSessionPeerAddrIndex, mplsLdpSessionPeerNextHopAddr=mplsLdpSessionPeerNextHopAddr, PYSNMP_MODULE_ID=mplsLdpStdMIB, mplsLdpEntityInitSessionThreshold=mplsLdpEntityInitSessionThreshold, mplsLdpLspFecSegment=mplsLdpLspFecSegment, mplsLdpPathVectorLimitMismatch=mplsLdpPathVectorLimitMismatch, mplsLdpNotifications=mplsLdpNotifications, mplsLdpEntityRowStatus=mplsLdpEntityRowStatus, mplsFecAddrPrefixLength=mplsFecAddrPrefixLength, mplsLdpLspFecEntry=mplsLdpLspFecEntry, mplsLdpEntityStatsTable=mplsLdpEntityStatsTable, mplsLdpLsrId=mplsLdpLsrId, mplsLdpSessionRole=mplsLdpSessionRole, mplsLdpEntityOperStatus=mplsLdpEntityOperStatus, mplsLdpModuleReadOnlyCompliance=mplsLdpModuleReadOnlyCompliance, mplsLdpLspFecRowStatus=mplsLdpLspFecRowStatus, mplsLdpConformance=mplsLdpConformance, mplsLdpHelloAdjacencyEntry=mplsLdpHelloAdjacencyEntry, mplsFecStorageType=mplsFecStorageType, mplsLdpEntityKeepAliveHoldTimer=mplsLdpEntityKeepAliveHoldTimer, mplsLdpSessionEntry=mplsLdpSessionEntry, mplsLdpEntityStatsSessionRejectedMaxPduErrors=mplsLdpEntityStatsSessionRejectedMaxPduErrors, mplsOutSegmentLdpLspEntry=mplsOutSegmentLdpLspEntry, mplsLdpEntityStatsBadMessageLengthErrors=mplsLdpEntityStatsBadMessageLengthErrors, mplsLdpLspFecTable=mplsLdpLspFecTable, mplsLdpEntityStatsBadLdpIdentifierErrors=mplsLdpEntityStatsBadLdpIdentifierErrors, mplsLdpEntityLdpId=mplsLdpEntityLdpId, mplsLdpLspFecSegmentIndex=mplsLdpLspFecSegmentIndex, mplsLdpNotificationsGroup=mplsLdpNotificationsGroup, mplsLdpEntityStatsSessionRejectedNoHelloErrors=mplsLdpEntityStatsSessionRejectedNoHelloErrors, mplsLdpPeerLabelDistMethod=mplsLdpPeerLabelDistMethod, mplsLdpSessionStatsEntry=mplsLdpSessionStatsEntry, mplsLdpSessionDiscontinuityTime=mplsLdpSessionDiscontinuityTime, mplsLdpLspFecLastChange=mplsLdpLspFecLastChange, mplsLdpEntityDiscontinuityTime=mplsLdpEntityDiscontinuityTime, mplsOutSegmentLdpLspTable=mplsOutSegmentLdpLspTable, mplsLdpEntityStatsShutdownSentNotifications=mplsLdpEntityStatsShutdownSentNotifications, mplsLdpEntityStatsSessionRejectedAdErrors=mplsLdpEntityStatsSessionRejectedAdErrors, mplsLdpEntityMaxPduLength=mplsLdpEntityMaxPduLength, mplsFecAddr=mplsFecAddr, mplsLdpCompliances=mplsLdpCompliances, mplsOutSegmentLdpLspLabelType=mplsOutSegmentLdpLspLabelType, mplsLdpSessionStatsUnknownTlvErrors=mplsLdpSessionStatsUnknownTlvErrors, mplsLdpLsrObjects=mplsLdpLsrObjects, mplsInSegmentLdpLspEntry=mplsInSegmentLdpLspEntry, mplsLdpEntityStatsKeepAliveTimerExpErrors=mplsLdpEntityStatsKeepAliveTimerExpErrors, mplsLdpLspFecIndex=mplsLdpLspFecIndex, mplsInSegmentLdpLspTable=mplsInSegmentLdpLspTable, mplsLdpEntityTcpPort=mplsLdpEntityTcpPort, mplsFecIndexNext=mplsFecIndexNext, mplsFecObjects=mplsFecObjects, mplsLdpSessionPeerAddrTable=mplsLdpSessionPeerAddrTable, mplsLdpSessionKeepAliveTime=mplsLdpSessionKeepAliveTime, mplsLdpEntityStatsEntry=mplsLdpEntityStatsEntry, mplsOutSegmentLdpLspIndex=mplsOutSegmentLdpLspIndex, mplsLdpGroups=mplsLdpGroups, mplsLdpEntityUdpDscPort=mplsLdpEntityUdpDscPort, mplsFecEntry=mplsFecEntry, mplsLdpPeerLastChange=mplsLdpPeerLastChange, mplsFecAddrType=mplsFecAddrType, mplsLdpEntityStatsMalformedTlvValueErrors=mplsLdpEntityStatsMalformedTlvValueErrors, mplsFecIndex=mplsFecIndex, mplsLdpSessionStatsUnknownMesTypeErrors=mplsLdpSessionStatsUnknownMesTypeErrors, mplsLdpEntityAdminStatus=mplsLdpEntityAdminStatus, mplsLdpEntityTransportAddrKind=mplsLdpEntityTransportAddrKind, mplsLdpEntityIndex=mplsLdpEntityIndex, mplsLdpEntityTargetPeerAddrType=mplsLdpEntityTargetPeerAddrType, mplsLdpObjects=mplsLdpObjects, mplsLdpHelloAdjacencyHoldTime=mplsLdpHelloAdjacencyHoldTime, mplsLdpEntityStatsShutdownReceivedNotifications=mplsLdpEntityStatsShutdownReceivedNotifications)



#
# PySNMP MIB module RSTP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/RSTP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:27:26 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion")
( dot1dStp, dot1dStpPortEntry, ) = mibBuilder.importSymbols("BRIDGE-MIB", "dot1dStp", "dot1dStpPortEntry")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Counter32, Gauge32, IpAddress, Integer32, Counter64, ObjectIdentity, MibIdentifier, ModuleIdentity, TimeTicks, Unsigned32, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, iso, mib_2, NotificationType, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "Gauge32", "IpAddress", "Integer32", "Counter64", "ObjectIdentity", "MibIdentifier", "ModuleIdentity", "TimeTicks", "Unsigned32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "iso", "mib-2", "NotificationType")
( TextualConvention, TruthValue, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "TruthValue", "DisplayString")
rstpMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 134)).setRevisions(("2005-12-07 00:00",))
if mibBuilder.loadTexts: rstpMIB.setLastUpdated('200512070000Z')
if mibBuilder.loadTexts: rstpMIB.setOrganization('IETF Bridge MIB Working Group')
if mibBuilder.loadTexts: rstpMIB.setContactInfo('Email: Bridge-mib@ietf.org')
if mibBuilder.loadTexts: rstpMIB.setDescription('The Bridge MIB Extension module for managing devices\n            that support the Rapid Spanning Tree Protocol defined\n            by IEEE 802.1w.\n\n            Copyright (C) The Internet Society (2005).  This version of\n            this MIB module is part of RFC 4318; See the RFC itself for\n            full legal notices.')
rstpNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 134, 0))
rstpObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 134, 1))
rstpConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 134, 2))
dot1dStpVersion = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 16), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 2,))).clone(namedValues=NamedValues(("stpCompatible", 0), ("rstp", 2),)).clone('rstp')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpVersion.setDescription("The version of Spanning Tree Protocol the bridge is\n            currently running.  The value 'stpCompatible(0)'\n            indicates the Spanning Tree Protocol specified in\n            IEEE 802.1D-1998 and 'rstp(2)' indicates the Rapid\n            Spanning Tree Protocol specified in IEEE 802.1w and\n            clause 17 of 802.1D-2004.  The values are directly from\n            the IEEE standard.  New values may be defined as future\n            versions of the protocol become available.\n\n            The value of this object MUST be retained across\n            reinitializations of the management system.")
dot1dStpTxHoldCount = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 17), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10)).clone(3)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpTxHoldCount.setDescription('The value used by the Port Transmit state machine to limit\n            the maximum transmission rate.\n\n            The value of this object MUST be retained across\n            reinitializations of the management system.')
dot1dStpExtPortTable = MibTable((1, 3, 6, 1, 2, 1, 17, 2, 19), )
if mibBuilder.loadTexts: dot1dStpExtPortTable.setDescription('A table that contains port-specific Rapid Spanning Tree\n            information.')
dot1dStpExtPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 2, 19, 1), )
dot1dStpPortEntry.registerAugmentions(("RSTP-MIB", "dot1dStpExtPortEntry"))
dot1dStpExtPortEntry.setIndexNames(*dot1dStpPortEntry.getIndexNames())
if mibBuilder.loadTexts: dot1dStpExtPortEntry.setDescription('A list of Rapid Spanning Tree information maintained by\n            each port.')
dot1dStpPortProtocolMigration = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 19, 1, 1), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpPortProtocolMigration.setDescription('When operating in RSTP (version 2) mode, writing true(1)\n            to this object forces this port to transmit RSTP BPDUs.\n            Any other operation on this object has no effect and\n            it always returns false(2) when read.')
dot1dStpPortAdminEdgePort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 19, 1, 2), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpPortAdminEdgePort.setDescription("The administrative value of the Edge Port parameter.  A\n            value of true(1) indicates that this port should be\n            assumed as an edge-port, and a value of false(2) indicates\n            that this port should be assumed as a non-edge-port.\n            Setting this object will also cause the corresponding\n            instance of dot1dStpPortOperEdgePort to change to the\n            same value.  Note that even when this object's value\n            is true, the value of the corresponding instance of\n            dot1dStpPortOperEdgePort can be false if a BPDU has\n            been received.\n\n            The value of this object MUST be retained across\n            reinitializations of the management system.")
dot1dStpPortOperEdgePort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 19, 1, 3), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpPortOperEdgePort.setDescription('The operational value of the Edge Port parameter.  The\n            object is initialized to the value of the corresponding\n            instance of dot1dStpPortAdminEdgePort.  When the\n            corresponding instance of dot1dStpPortAdminEdgePort is\n            set, this object will be changed as well.  This object\n            will also be changed to false on reception of a BPDU.')
dot1dStpPortAdminPointToPoint = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 19, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2,))).clone(namedValues=NamedValues(("forceTrue", 0), ("forceFalse", 1), ("auto", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpPortAdminPointToPoint.setDescription('The administrative point-to-point status of the LAN segment\n            attached to this port, using the enumeration values of the\n            IEEE 802.1w clause.  A value of forceTrue(0) indicates\n            that this port should always be treated as if it is\n            connected to a point-to-point link.  A value of\n            forceFalse(1) indicates that this port should be treated as\n            having a shared media connection.  A value of auto(2)\n            indicates that this port is considered to have a\n            point-to-point link if it is an Aggregator and all of its\n            members are aggregatable, or if the MAC entity\n            is configured for full duplex operation, either through\n            auto-negotiation or by management means.  Manipulating this\n            object changes the underlying adminPortToPortMAC.\n\n            The value of this object MUST be retained across\n            reinitializations of the management system.')
dot1dStpPortOperPointToPoint = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 19, 1, 5), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpPortOperPointToPoint.setDescription('The operational point-to-point status of the LAN segment\n            attached to this port.  It indicates whether a port is\n            considered to have a point-to-point connection.\n            If adminPointToPointMAC is set to auto(2), then the value\n            of operPointToPointMAC is determined in accordance with the\n            specific procedures defined for the MAC entity concerned,\n            as defined in IEEE 802.1w, clause 6.5.  The value is\n            determined dynamically; that is, it is re-evaluated whenever\n            the value of adminPointToPointMAC changes, and whenever\n            the specific procedures defined for the MAC entity evaluate\n            a change in its point-to-point status.')
dot1dStpPortAdminPathCost = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 19, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,200000000))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpPortAdminPathCost.setDescription("The administratively assigned value for the contribution\n            of this port to the path cost of paths toward the spanning\n            tree root.\n\n            Writing a value of '0' assigns the automatically calculated\n            default Path Cost value to the port.  If the default Path\n            Cost is being used, this object returns '0' when read.\n\n            This complements the object dot1dStpPortPathCost or\n            dot1dStpPortPathCost32, which returns the operational value\n            of the path cost.\n            The value of this object MUST be retained across\n            reinitializations of the management system.")
rstpGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 134, 2, 1))
rstpCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 134, 2, 2))
rstpBridgeGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 134, 2, 1, 1)).setObjects(*(("RSTP-MIB", "dot1dStpVersion"), ("RSTP-MIB", "dot1dStpTxHoldCount"),))
if mibBuilder.loadTexts: rstpBridgeGroup.setDescription('Rapid Spanning Tree information for the bridge.')
rstpPortGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 134, 2, 1, 2)).setObjects(*(("RSTP-MIB", "dot1dStpPortProtocolMigration"), ("RSTP-MIB", "dot1dStpPortAdminEdgePort"), ("RSTP-MIB", "dot1dStpPortOperEdgePort"), ("RSTP-MIB", "dot1dStpPortAdminPointToPoint"), ("RSTP-MIB", "dot1dStpPortOperPointToPoint"), ("RSTP-MIB", "dot1dStpPortAdminPathCost"),))
if mibBuilder.loadTexts: rstpPortGroup.setDescription('Rapid Spanning Tree information for individual ports.')
rstpCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 134, 2, 2, 1)).setObjects(*(("RSTP-MIB", "rstpBridgeGroup"), ("RSTP-MIB", "rstpPortGroup"),))
if mibBuilder.loadTexts: rstpCompliance.setDescription('The compliance statement for device support of Rapid\n            Spanning Tree Protocol (RSTP) bridging services.')
mibBuilder.exportSymbols("RSTP-MIB", dot1dStpExtPortTable=dot1dStpExtPortTable, dot1dStpPortAdminPointToPoint=dot1dStpPortAdminPointToPoint, rstpPortGroup=rstpPortGroup, rstpCompliance=rstpCompliance, dot1dStpPortOperEdgePort=dot1dStpPortOperEdgePort, PYSNMP_MODULE_ID=rstpMIB, dot1dStpExtPortEntry=dot1dStpExtPortEntry, rstpCompliances=rstpCompliances, rstpMIB=rstpMIB, dot1dStpPortProtocolMigration=dot1dStpPortProtocolMigration, rstpBridgeGroup=rstpBridgeGroup, dot1dStpPortAdminEdgePort=dot1dStpPortAdminEdgePort, rstpObjects=rstpObjects, rstpNotifications=rstpNotifications, dot1dStpPortOperPointToPoint=dot1dStpPortOperPointToPoint, rstpGroups=rstpGroups, dot1dStpTxHoldCount=dot1dStpTxHoldCount, rstpConformance=rstpConformance, dot1dStpPortAdminPathCost=dot1dStpPortAdminPathCost, dot1dStpVersion=dot1dStpVersion)
